pub struct EntityDefinition {Show 33 fields
pub color: String,
pub doc: Option<String>,
pub export_to_toc: bool,
pub field_defs: Vec<FieldDefinition>,
pub fill_opacity: f64,
pub height: i64,
pub hollow: bool,
pub identifier: String,
pub keep_aspect_ratio: bool,
pub limit_behavior: LimitBehavior,
pub limit_scope: LimitScope,
pub line_opacity: f64,
pub max_count: i64,
pub max_height: Option<i64>,
pub max_width: Option<i64>,
pub min_height: Option<i64>,
pub min_width: Option<i64>,
pub nine_slice_borders: Vec<i64>,
pub pivot_x: f64,
pub pivot_y: f64,
pub render_mode: RenderMode,
pub resizable_x: bool,
pub resizable_y: bool,
pub show_name: bool,
pub tags: Vec<String>,
pub tile_id: Option<i64>,
pub tile_opacity: f64,
pub tile_rect: Option<TilesetRectangle>,
pub tile_render_mode: TileRenderMode,
pub tileset_id: Option<i64>,
pub uid: i64,
pub ui_tile_rect: Option<TilesetRectangle>,
pub width: i64,
}Fields
color: StringBase entity color
doc: Option<String>User defined documentation for this element to provide help/tips to level designers.
export_to_toc: boolIf enabled, all instances of this entity will be listed in the project “Table of content” object.
field_defs: Vec<FieldDefinition>Array of field definitions
fill_opacity: f64height: i64Pixel height
hollow: boolidentifier: StringUser defined unique identifier
keep_aspect_ratio: boolOnly applies to entities resizable on both X/Y. If TRUE, the entity instance width/height will keep the same aspect ratio as the definition.
limit_behavior: LimitBehaviorPossible values: DiscardOldOnes, PreventAdding, MoveLastOne
limit_scope: LimitScopeIf TRUE, the maxCount is a “per world” limit, if FALSE, it’s a “per level”. Possible
values: PerLayer, PerLevel, PerWorld
line_opacity: f64max_count: i64Max instances count
max_height: Option<i64>Max pixel height (only applies if the entity is resizable on Y)
max_width: Option<i64>Max pixel width (only applies if the entity is resizable on X)
min_height: Option<i64>Min pixel height (only applies if the entity is resizable on Y)
min_width: Option<i64>Min pixel width (only applies if the entity is resizable on X)
nine_slice_borders: Vec<i64>An array of 4 dimensions for the up/right/down/left borders (in this order) when using
9-slice mode for tileRenderMode.
If the tileRenderMode is not NineSlice, then
this array is empty.
See: https://en.wikipedia.org/wiki/9-slice_scaling
pivot_x: f64Pivot X coordinate (from 0 to 1.0)
pivot_y: f64Pivot Y coordinate (from 0 to 1.0)
render_mode: RenderModePossible values: Rectangle, Ellipse, Tile, Cross
resizable_x: boolIf TRUE, the entity instances will be resizable horizontally
resizable_y: boolIf TRUE, the entity instances will be resizable vertically
show_name: boolDisplay entity name in editor
An array of strings that classifies this entity
tile_id: Option<i64>WARNING: this deprecated value is no longer exported since version 1.2.0 Replaced
by: tileRect
tile_opacity: f64tile_rect: Option<TilesetRectangle>An object representing a rectangle from an existing Tileset
tile_render_mode: TileRenderModeAn enum describing how the the Entity tile is rendered inside the Entity bounds. Possible
values: Cover, FitInside, Repeat, Stretch, FullSizeCropped,
FullSizeUncropped, NineSlice
tileset_id: Option<i64>Tileset ID used for optional tile display
uid: i64Unique Int identifier
ui_tile_rect: Option<TilesetRectangle>This tile overrides the one defined in tileRect in the UI
width: i64Pixel width