pub struct EntityInstance {Show 14 fields
pub grid: Vec<i64>,
pub identifier: String,
pub pivot: Vec<f64>,
pub smart_color: String,
pub tags: Vec<String>,
pub tile: Option<TilesetRectangle>,
pub world_x: i64,
pub world_y: i64,
pub def_uid: i64,
pub field_instances: Vec<FieldInstance>,
pub height: i64,
pub iid: String,
pub px: Vec<i64>,
pub width: i64,
}Fields
grid: Vec<i64>Grid-based coordinates ([x,y] format)
identifier: StringEntity definition identifier
pivot: Vec<f64>Pivot coordinates ([x,y] format, values are from 0 to 1) of the Entity
smart_color: StringThe entity “smart” color, guessed from either Entity definition, or one its field instances.
Array of tags defined in this Entity definition
tile: Option<TilesetRectangle>Optional TilesetRect used to display this entity (it could either be the default Entity tile, or some tile provided by a field value, like an Enum).
world_x: i64X world coordinate in pixels
world_y: i64Y world coordinate in pixels
def_uid: i64Reference of the Entity definition UID
field_instances: Vec<FieldInstance>An array of all custom fields and their values.
height: i64Entity height in pixels. For non-resizable entities, it will be the same as Entity definition.
iid: StringUnique instance identifier
px: Vec<i64>Pixel coordinates ([x,y] format) in current level coordinate space. Don’t forget
optional layer offsets, if they exist!
width: i64Entity width in pixels. For non-resizable entities, it will be the same as Entity definition.