pub struct EnumValueDefinition {
pub tile_src_rect: Option<Vec<i64>>,
pub color: i64,
pub id: String,
pub tile_id: Option<i64>,
pub tile_rect: Option<TilesetRectangle>,
}Fields
tile_src_rect: Option<Vec<i64>>WARNING: this deprecated value is no longer exported since version 1.4.0 Replaced
by: tileRect
color: i64Optional color
id: StringEnum value
tile_id: Option<i64>WARNING: this deprecated value is no longer exported since version 1.4.0 Replaced
by: tileRect
tile_rect: Option<TilesetRectangle>Optional tileset rectangle to represents this value