pub struct FieldInstance {
pub identifier: String,
pub tile: Option<TilesetRectangle>,
pub field_instance_type: String,
pub value: Option<Value>,
pub def_uid: i64,
pub real_editor_values: Vec<Option<Value>>,
}Fields
identifier: StringField definition identifier
tile: Option<TilesetRectangle>Optional TilesetRect used to display this field (this can be the field own Tile, or some other Tile guessed from the value, like an Enum).
field_instance_type: StringType of the field, such as Int, Float, String, Enum(my_enum_name), Bool,
etc.
NOTE: if you enable the advanced option Use Multilines type, you will have
“Multilines” instead of “String” when relevant.
value: Option<Value>Actual value of the field instance. The value type varies, depending on __type:
- For classic types (ie. Integer, Float, Boolean, String, Text and FilePath), you
just get the actual value with the expected type.
- For Color, the value is an hexadecimal string using “#rrggbb” format.
- For Enum, the value is a String representing the selected enum value.
- For Point, the value is a GridPoint object.
- For Tile, the value is a TilesetRect object.
- For EntityRef, the value is an EntityReferenceInfos object.
If the field is an array, then this__valuewill also be a JSON array.
def_uid: i64Reference of the Field definition UID
real_editor_values: Vec<Option<Value>>Editor internal raw values