pub struct NeighbourLevel {
pub dir: String,
pub level_iid: String,
pub level_uid: Option<i64>,
}Expand description
Nearby level info
Fields
dir: StringA single lowercase character tipping on the level location (north, south, west,
east).
Since 1.4.0, this character value can also be < (neighbour depth is
lower), > (neighbour depth is greater) or o (levels overlap and share the same world
depth).
level_iid: StringNeighbour Instance Identifier
level_uid: Option<i64>WARNING: this deprecated value is no longer exported since version 1.2.0 Replaced
by: levelIid