pub struct TileInstance {
pub a: f64,
pub d: Vec<i64>,
pub f: i64,
pub px: Vec<i64>,
pub src: Vec<i64>,
pub t: i64,
}Expand description
This structure represents a single tile from a given Tileset.
Fields
a: f64Alpha/opacity of the tile (0-1, defaults to 1)
d: Vec<i64>Internal data used by the editor.
For auto-layer tiles: [ruleId, coordId].
For tile-layer tiles: [coordId].
f: i64“Flip bits”, a 2-bits integer to represent the mirror transformations of the tile.
- Bit 0 = X flip
- Bit 1 = Y flip
Examples: f=0 (no flip), f=1 (X flip only), f=2 (Y flip only), f=3 (both flips)
px: Vec<i64>Pixel coordinates of the tile in the layer ([x,y] format). Don’t forget optional
layer offsets, if they exist!
src: Vec<i64>Pixel coordinates of the tile in the tileset ([x,y] format)
t: i64The Tile ID in the corresponding tileset.