pub struct TilesetDefinition {Show 17 fields
pub c_hei: i64,
pub c_wid: i64,
pub cached_pixel_data: Option<HashMap<String, Option<Value>>>,
pub custom_data: Vec<TileCustomMetadata>,
pub embed_atlas: Option<EmbedAtlas>,
pub enum_tags: Vec<EnumTagValue>,
pub identifier: String,
pub padding: i64,
pub px_hei: i64,
pub px_wid: i64,
pub rel_path: Option<String>,
pub saved_selections: Vec<HashMap<String, Option<Value>>>,
pub spacing: i64,
pub tags: Vec<String>,
pub tags_source_enum_uid: Option<i64>,
pub tile_grid_size: i64,
pub uid: i64,
}Expand description
The Tileset definition is the most important part among project definitions. It
contains some extra informations about each integrated tileset. If you only had to parse
one definition section, that would be the one.
Fields
c_hei: i64Grid-based height
c_wid: i64Grid-based width
cached_pixel_data: Option<HashMap<String, Option<Value>>>The following data is used internally for various optimizations. It’s always synced with source image changes.
custom_data: Vec<TileCustomMetadata>An array of custom tile metadata
embed_atlas: Option<EmbedAtlas>If this value is set, then it means that this atlas uses an internal LDtk atlas image
instead of a loaded one. Possible values: <null>, LdtkIcons
Tileset tags using Enum values specified by tagsSourceEnumId. This array contains 1
element per Enum value, which contains an array of all Tile IDs that are tagged with it.
identifier: StringUser defined unique identifier
padding: i64Distance in pixels from image borders
px_hei: i64Image height in pixels
px_wid: i64Image width in pixels
rel_path: Option<String>Path to the source file, relative to the current project JSON file
It can be null
if no image was provided, or when using an embed atlas.
saved_selections: Vec<HashMap<String, Option<Value>>>Array of group of tiles selections, only meant to be used in the editor
spacing: i64Space in pixels between all tiles
An array of user-defined tags to organize the Tilesets
Optional Enum definition UID used for this tileset meta-data
tile_grid_size: i64uid: i64Unique Intidentifier